Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1929)

Unified Diff: cc/surfaces/surface_manager.h

Issue 2661543002: Rename LocalFrameId to LocalSurfaceId (Closed)
Patch Set: c Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « cc/surfaces/surface_id_allocator.cc ('k') | cc/surfaces/surface_manager.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: cc/surfaces/surface_manager.h
diff --git a/cc/surfaces/surface_manager.h b/cc/surfaces/surface_manager.h
index e8f53b8f0bf19ba47e19a09ff7cd6e90b718f56e..4eecb57a9739426a5bebcf0c44c430cfedde4379 100644
--- a/cc/surfaces/surface_manager.h
+++ b/cc/surfaces/surface_manager.h
@@ -250,8 +250,8 @@ class CC_SURFACES_EXPORT SurfaceManager
// aren't GC'd before a real reference is added. This is basically a
// collection of surface ids, for example:
// SurfaceId surface_id(key, value[index]);
- // The LocalFrameIds are stored in the order the surfaces are created in.
- std::unordered_map<FrameSinkId, std::vector<LocalFrameId>, FrameSinkIdHash>
+ // The LocalSurfaceIds are stored in the order the surfaces are created in.
+ std::unordered_map<FrameSinkId, std::vector<LocalSurfaceId>, FrameSinkIdHash>
temp_references_;
base::WeakPtrFactory<SurfaceManager> weak_factory_;
« no previous file with comments | « cc/surfaces/surface_id_allocator.cc ('k') | cc/surfaces/surface_manager.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698